==> errorlogger-0.0.32.tar.gz: errorlogger-0.0.32/ErrorLogger/logger.py <==
import logging
import configparser
import threading
import time
import requests
import pickle
import os
import datetime
from functools import wraps

class ErrorLogger:
    def __init__(self, config_file='config.ini'):
        # Read the config file
        config = configparser.ConfigParser()
        if not os.path.exists(config_file):
            raise FileNotFoundError("Configuration file not found.")
        config.read(config_file)

        # Validate necessary configuration is present
        if 'DEFAULT' not in config or 'apm_baseurl' not in config['DEFAULT']:
            raise ValueError("Configuration file is missing required 'apm_baseurl'.")

        # Get the APM base URL
        self.apm_baseurl = config['DEFAULT']['apm_baseurl']

        # Configure the logger
        self.logger = logging.getLogger('ErrorLogger')
        self.logger.setLevel(logging.INFO)

        # File handler for log messages
        file_handler = logging.FileHandler('error_logs.log')
        file_handler.setLevel(logging.ERROR)
        file_formatter = logging.Formatter('%(asctime)s %(levelname)s: %(message)s')
        file_handler.setFormatter(file_formatter)
        self.logger.addHandler(file_handler)

        # Console handler for debugging purposes
        console_handler = logging.StreamHandler()
        console_handler.setLevel(logging.INFO)
        console_formatter = logging.Formatter('%(asctime)s %(levelname)s: %(message)s')
        console_handler.setFormatter(console_formatter)
        self.logger.addHandler(console_handler)

        # Initialize logs storage
        self.logs_storage_file = 'logs.pkl'

        # Start a thread to continuously collect logs
        self.running = True
        self.collector_thread = threading.Thread(target=self._start_collecting_logs)
        self.collector_thread.daemon = True
        self.collector_thread.start()

    def stop(self):
        """ Stop the logging thread. """
        self.running = False
        self.collector_thread.join()

    def _start_collecting_logs(self):
        while self.running:
            self.collect_logs()
            time.sleep(60)  # Fetch logs every 60 seconds

    def collect_logs(self):
        try:
            # Fetch data from the URL
            response = requests.get(self.apm_baseurl)
            response.raise_for_status()  # Raise an exception for HTTP error responses

            # Check the content type
            content_type = response.headers.get('Content-Type', '')

            if 'application/json' in content_type:
                try:
                    # Try to parse JSON data
                    logs = response.json()
                    if not isinstance(logs, dict):
                        # Ensure that the parsed data is a dictionary
                        error_info = f"Invalid JSON format: {response.text}"
                        self.logger.error(error_info)
                        logs = {'error': error_info}
                except ValueError as e:
                    # Handle JSON parsing errors
                    error_info = f"JSON parsing error: {str(e)}"
                    self.logger.error(error_info)
                    logs = {'error': error_info}
            else:
                # Handle cases where the content type is not JSON
                error_info = f"Unexpected content type: {content_type}. Data: {response.text}"
                self.logger.error(error_info)
                logs = {'error': error_info}

            # Save the logs
            self._save_logs(logs)

        except requests.exceptions.RequestException as e:
            # Handle request errors
            error_info = f"Request exception: {str(e)}"
            self.logger.error(error_info)
            self._save_logs({'error': error_info})

    def _save_logs(self, logs):
        formatted_log = self._format_log(logs)
        try:
            with open(self.logs_storage_file, 'ab') as file:
                pickle.dump(formatted_log, file)
        except Exception as e:
            self.logger.error(f"Failed to save logs: {e}")

    def _format_log(self, log_data):
        timestamp = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S,%f')[:-3]
        level = 'ERROR'  # Assuming error level; adjust as necessary
        message = log_data if isinstance(log_data, str) else str(log_data)
        return f"{timestamp} {level}: {message}"

    def log_exception(self, exception: Exception, message: str = None):
        error_message = message if message else str(exception)
        self.logger.error(f"Exception: {error_message}")

    def convert_logs_to_pickle(self, log_file='error_logs.log', pickle_file='logs.pkl'):
        """Convert the contents of the log file to a pickle file."""
        if not os.path.isfile(log_file):
            self.logger.error(f"Log file {log_file} not found.")
            return

        try:
            with open(log_file, 'r') as file:
                log_data = file.readlines()

            with open(pickle_file, 'wb') as file:
                pickle.dump(log_data, file)
            self.logger.info(f"Log data successfully converted to {pickle_file}.")
        except Exception as e:
            self.logger.error(f"Failed to convert logs to pickle file: {e}")

# Define the capture_exception decorator
def capture_exception(logger_instance):
    def decorator(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            try:
                return func(*args, **kwargs)
            except Exception as e:
                logger_instance.log_exception(e)
                raise
        return wrapper
    return decorator

==> errorlogger-0.0.34.tar.gz: errorlogger-0.0.34/ErrorLogger/logger.py <==
import logging
import configparser
import threading
import time
import requests
import os
from functools import wraps

class ErrorLogger:
    def __init__(self, config_file='config.ini'):
        # Read the config file
        config = configparser.ConfigParser()
        if not os.path.exists(config_file):
            raise FileNotFoundError("Configuration file not found.")
        config.read(config_file)

        # Validate necessary configuration is present
        if 'DEFAULT' not in config or 'apm_baseurl' not in config['DEFAULT']:
            raise ValueError("Configuration file is missing required 'apm_baseurl'.")
        if 'api_endpoint' not in config['DEFAULT']:
            raise ValueError("Configuration file is missing required 'api_endpoint'.")

        # Get the APM base URL and API endpoint
        self.apm_baseurl = config['DEFAULT']['apm_baseurl']
        self.api_endpoint = config['DEFAULT']['api_endpoint']
        self.app_name = config['DEFAULT'].get('apm_app_name', 'UnknownApp')
        self.tag = config['DEFAULT'].get('tag', 'General')

        # Configure the logger
        self.logger = logging.getLogger('ErrorLogger')
        self.logger.setLevel(logging.INFO)

        # Console handler for debugging purposes
        console_handler = logging.StreamHandler()
        console_handler.setLevel(logging.INFO)
        console_formatter = logging.Formatter('%(asctime)s %(levelname)s: %(message)s')
        console_handler.setFormatter(console_formatter)
        self.logger.addHandler(console_handler)

        # Start a thread to continuously collect logs
        self.running = True
        self.collector_thread = threading.Thread(target=self._start_collecting_logs)
        self.collector_thread.daemon = True
        self.collector_thread.start()

    def stop(self):
        """ Stop the logging thread. """
        self.running = False
        self.collector_thread.join()

    def _start_collecting_logs(self):
        while self.running:
            self.collect_logs()
            time.sleep(60)  # Fetch logs every 60 seconds

    def collect_logs(self):
        try:
            # Fetch data from the URL
            response = requests.get(self.apm_baseurl)
            response.raise_for_status()  # Raise an exception for HTTP error responses

            # Check the content type
            content_type = response.headers.get('Content-Type', '')

            if 'application/json' in content_type:
                try:
                    # Try to parse JSON data
                    logs = response.json()
                    if not isinstance(logs, dict):
                        # Ensure that the parsed data is a dictionary
                        error_info = f"Invalid JSON format: {response.text}"
                        self.logger.error(error_info)
                        logs = {'error': error_info}
                except ValueError as e:
                    # Handle JSON parsing errors
                    error_info = f"JSON parsing error: {str(e)}"
                    self.logger.error(error_info)
                    logs = {'error': error_info}
            else:
                # Handle cases where the content type is not JSON
                error_info = f"Unexpected content type: {content_type}. Data: {response.text}"
                self.logger.error(error_info)
                logs = {'error': error_info}

            # Prepare the log data for sending
            log_data = {
                "app_name": self.app_name,
                "app_type_id": 1,  # Example value, modify as needed
                "user_id": 1,  # Example value, modify as needed
                "category": self.tag,
                "category_description": "Auto-generated log",
                "exception_details": logs.get('error', 'No error'),
                "message": logs.get('message', ''),
                "stack_trace": logs.get('stack_trace', '')
            }

            # Send logs to the API
            self._send_logs_to_api(log_data)

        except requests.exceptions.RequestException as e:
            # Handle request errors
            error_info = f"Request exception: {str(e)}"
            self.logger.error(error_info)
            self._send_logs_to_api({'exception_details': error_info})

    def _send_logs_to_api(self, logs):
        try:
            response = requests.post(self.api_endpoint, json=logs)
            response.raise_for_status()  # Ensure that the request was successful
            self.logger.info("Logs sent to API successfully.")
        except requests.exceptions.RequestException as e:
            self.logger.error(f"Failed to send logs to API: {e}")

    def log_exception(self, exception: Exception, message: str = None):
        error_message = message if message else str(exception)
        self.logger.error(f"Exception: {error_message}")
        log_data = {
            "app_name": self.app_name,
            "app_type_id": 1,
            "user_id": 1,
            "category": self.tag,
            "category_description": "Exception captured",
            "exception_details": error_message,
            "message": "",
            "stack_trace": ""
        }
        self._send_logs_to_api(log_data)

def capture_exception(logger_instance):
    def decorator(func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            try:
                return func(*args, **kwargs)
            except Exception as e:
                # Log the exception using the provided logger instance
                logger_instance.log_exception(e)
                # Re-raise the exception to ensure Flask handles it
                raise
        return wrapper
    return decorator
